/*
 * Copyright (c) 2005-2010 KOM – Multimedia Communications Lab
 *
 * This file is part of Simonstrator.KOM.
 * 
 * Simonstrator.KOM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 * 
 * PeerfactSim.KOM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with PeerfactSim.KOM.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

package de.tudarmstadt.maki.simonstrator.api.component.sensor;

import de.tudarmstadt.maki.simonstrator.api.Monitor;
import de.tudarmstadt.maki.simonstrator.api.Monitor.Level;
import de.tudarmstadt.maki.simonstrator.api.component.HostComponent;

/**
 * All sensor components should implement this interface
 * 
 * @author Bjoern Richerzhagen, Lukas Wehrstein added methods
 * 
 */
public interface SensorComponent extends HostComponent {

	/**
	 * Implement a sensor test
	 * 
	 * @return true, if sensor works fine (default)
	 */
	public default boolean testSensor() {
		Monitor.log(getClass(), Level.INFO, "Sensor test completed.");
		return true;
	}

	/**
	 * Return Sensor data from the Sensor
	 * 
	 * @return the sensor data
	 */
	public default double getSensorData() {
		return 0;
	}

	/**
	 * How many bytes the sensor can maximal return
	 * 
	 * @return the size in Bytes
	 * 
	 *         Byte: 1 Byte, Char: 1 Byte, Integer: 4 Bytes, Float: 4 Bytes,
	 *         Double: 8 Bytes
	 * 
	 */
	public default int getSensorDataSize() {
		return 0;
	}

	/**
	 * Returns a String representation of the Sensor name
	 * 
	 * @return the name
	 */
	public default String getName() {
		return "NoNameSensor";
	};

}
